#!/bin/bash
#
# script: til <rob DOT til DOT freedman AT googlemail DOT com>
#
set -x -u -e

name=htop
version=0.8.3
#
build=${build:-62.1}
arch=${arch:-i486}
cpu=${cpu:-i686}

MYFLAGS="-O2 -march=$arch -mtune=$cpu"

#$(echo $version |tr -d '-')
pkgname=$name-$version
package=$pkgname-$arch-$build

PKG_URL="http://htop.sourceforge.net/"
SRC_URL="http://dfn.dl.sourceforge.net/project/htop/htop/$version/$pkgname.tar.gz"
PKG_SRC=""
PKG_DEP="ncurses"
#wget -N $SRC_URL

# build directory
CWD=`pwd`
TMP=${TMP:-$CWD}
SRC=$TMP/$pkgname
PKG=$TMP/$package

# prepare build directory
[ -d $SRC ] && rm -fr $SRC
[ -d $PKG ] && rm -fr $PKG
#
mkdir -p $SRC $PKG/{install,usr/{src,doc}/$pkgname}
mkdir -p $PKG/usr/share/icons/hicolor/{16x16,32x32,48x48}/apps

#
tar xf $CWD/$pkgname.tar.gz -C $TMP
cd $SRC
# ./configure --help

CFLAGS="$MYFLAGS" \
./configure \
	--prefix=/usr --mandir=/usr/man \
	--disable-static --enable-unicode # --enable-taskstats

make
make DESTDIR=$PKG install

# docs
cp -a AUTHORS COPYING ChangeLog NEWS README TODO \
    $PKG/usr/doc/$pkgname
#
for i in AUTHORS  LICENSE  README  VERSION; do
	cp -a plpa-1.1/$i $PKG/usr/doc/$pkgname/$i.plpa
done

gzip -9 $PKG/usr/man/man1/htop.1

# icons
mv $PKG/usr/share/pixmaps/htop.png \
	$PKG/usr/share/icons/hicolor/32x32/apps/htop.png
#
convert htop.png -resize 16x16 \
	$PKG/usr/share/icons/hicolor/16x16/apps/htop.png
convert htop.png -resize 48x48 \
	$PKG/usr/share/icons/hicolor/48x48/apps/htop.png

# copy build script
cp $CWD/build-$name.sh $PKG/usr/src/$pkgname

# copy slack description
#    |-----handy-ruler------------------------------------------------------|
cat <<"EOF" > $PKG/install/slack-desc
htop: htop (interactive text-mode process viewer for Linux)
htop:
htop: htop is an interactive text-mode process viewer for Linux 
htop: utilizing the /proc filesystem.
htop:
EOF

# remove symbols
strip --strip-unneeded $PKG/usr/bin/htop

#find $PKG | xargs file | grep -e "executable" -e "shared object"  \
# | grep ELF | tee $CWD/syms | cut -s -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null

# clean up
find $PKG -type d -empty -delete

cd $PKG
fakeroot /sbin/makepkg -l y -c n $CWD/$package.txz

cd $CWD
echo $PKG_DEP >$package.dep
#depfinder $PKG >$package.dep
echo "$PKG_SRC" >$package.src
md5sum $package.txz >$package.md5

